Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1634)

Unified Diff: bindings/dart/scripts/dart_methods.py

Issue 558803003: Roll IDL Dartium 37 (r181675) (Closed) Base URL: https://dart.googlecode.com/svn/third_party/WebCore
Patch Set: Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « bindings/dart/scripts/dart_interface.py ('k') | bindings/dart/scripts/dart_utilities.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: bindings/dart/scripts/dart_methods.py
diff --git a/bindings/dart/scripts/dart_methods.py b/bindings/dart/scripts/dart_methods.py
index aac8f5efe4b0cf1ac3b9218bfacc48f84f98784c..03d64a5972e66b14cc47d5ec3f7c1250bce37c8c 100644
--- a/bindings/dart/scripts/dart_methods.py
+++ b/bindings/dart/scripts/dart_methods.py
@@ -140,11 +140,11 @@ def generate_method(interface, method):
'is_raises_exception': is_raises_exception,
'is_read_only': 'ReadOnly' in extended_attributes,
'is_static': is_static,
# FIXME(terry): StrictTypeChecking no longer supported; TypeChecking is
# new extended attribute.
'is_strict_type_checking':
- 'StrictTypeChecking' in extended_attributes or
- 'StrictTypeChecking' in interface.extended_attributes,
+ 'DartStrictTypeChecking' in extended_attributes or
+ 'DartStrictTypeChecking' in interface.extended_attributes,
'is_variadic': arguments and arguments[-1].is_variadic,
'measure_as': DartUtilities.measure_as(method), # [MeasureAs]
'name': name,
@@ -204,7 +204,7 @@ def generate_argument(interface, method, argument, index):
'is_nullable': idl_type.is_nullable,
# Only expose as optional if no default value.
'is_optional': argument.is_optional and not (this_has_default or argument.default_value),
- 'is_strict_type_checking': 'StrictTypeChecking' in extended_attributes,
+ 'is_strict_type_checking': 'DartStrictTypeChecking' in extended_attributes,
'is_variadic_wrapper_type': is_variadic_wrapper_type,
'vector_type': 'WillBeHeapVector' if use_heap_vector_type else 'Vector',
'is_wrapper_type': idl_type.is_wrapper_type,
@@ -140,11 +140,11 @@ def generate_method(interface, method):
'is_read_only': 'ReadOnly' in extended_attributes,
'is_static': is_static,
- # FIXME(terry): StrictTypeChecking no longer supported; TypeChecking is
+ # FIXME(terry): DartStrictTypeChecking no longer supported; TypeChecking is
# new extended attribute.
'is_strict_type_checking':
« no previous file with comments | « bindings/dart/scripts/dart_interface.py ('k') | bindings/dart/scripts/dart_utilities.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698